.. _reference:

========
Overview
========

**Technical reference**.
API reference, model reference, contribution guide, changelog. To be used while working with Pyxel.

* :doc:`apireference`
* :doc:`models`
* :doc:`contributing`
* :doc:`changelog`

